<template>
  <div style="flex: 1">
    <a-table :columns="columns" :data-source="dataSource" bordered :pagination="ipagination"
             :scroll="{y:265}" :customRow="customRow" :size="size" rowKey="docId" @change="handleTableChange">

    </a-table>

    <DocumentModal ref="modalForm" @ok="modalFormOk"/>

    <NcDocumentAssignModal :size="size" ref="documentAssignModalRef"
                           :currentDocumentInfo="currentRightClickedDocumentInfo"/>
  </div>
</template>

<script>
import { getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import DocumentModal from '../../../../common/DocumentModal'
import NcDocumentAssignModal from './NcDocumentAssignModal'

export default {
  name: 'NcDocumentTableList',
  components: { NcDocumentAssignModal, DocumentModal },
  mixins: [JeecgListMixin],
  props: {
    currentNCDocumentAttributionInfo: {
      type: Object
    },
    size: {
      type: String
    }
  },
  data() {
    return {
      disableMixinCreated: true,
      columns: [
        {
          title: '序号',
          dataIndex: 'rowIndex',
          key: 'rowIndex',
          width: 65,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '文件名称',
          dataIndex: 'docName',
          key: 'docName',
          align: 'center',
          width: 300,
          sorter: true
        },
        { title: '代码版本', dataIndex: 'docAlias', align: 'center' },
        {
          title: '出库状态',
          dataIndex: 'pullStatus_dictText',
          key: 'pullStatus',
          align: 'center',
          filters: [
            { text: '未出库', value: 1 },
            { text: '已出库', value: 2 }
          ]
        },
        {
          title: '状  态',
          dataIndex: 'docStatus_dictText',
          key: 'docStatus',
          align: 'center',
          filters: [
            { text: '设计', value: 1 },
            { text: '发布', value: 2 },
            { text: '归档', value: 3 }
          ]
        },
        { title: '系统指定版本', dataIndex: 'publishVersion', align: 'center', width: 200 },
        {
          title: '创建时间',
          dataIndex: 'createTime',
          align: 'center',
          width: 200,
          sorter: true
        }
      ],
      dataSource: [],
      currentRightClickedDocumentInfo: {},
      currentClickedDocumentInfo: {},
      url: {
        list: '/nc/doc/find/page'
      }
    }
  },
  watch: {
    currentNCDocumentAttributionInfo: {
      handler(value) {
        this.currentClickedDocumentInfo = {}
      },
      immediate: true
    }
  },
  created() {
    this.$bus.$on('tableMenuItemMethodTrigger', this.triggerCorrespondingMethod)
  },
  methods: {
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      console.log('currentNCDocumentAttributionInfo', this.currentNCDocumentAttributionInfo)
      const { attributionId, attributionType, docClassCode } = this.currentNCDocumentAttributionInfo
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) this.ipagination.current = 1
      var params = this.getQueryParams()//查询条件
      params.attributionId = attributionId
      params.attributionType = attributionType
      params.docClassCode = docClassCode
      if (!params) return false
      this.dataSource = []
      this.loading = true
      getAction(this.url.list + `/${this.ipagination.current}/${this.ipagination.pageSize}`, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          if (res.result.total) {
            this.ipagination.total = res.result.total
          } else {
            this.ipagination.total = 0
          }
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

    customRow(record) {
      return {
        style: {
          backgroundColor: this.currentClickedDocumentInfo.docId === record.docId ? '#BAE7FF' : 'transparent'
        },
        on: {
          contextmenu: event => {
            event.preventDefault()
            this.currentRightClickedDocumentInfo = Object.assign({ param: 'NC' }, record)
            this.$emit('handleTableContextMenuOpen', this.currentRightClickedDocumentInfo)
          },
          click: () => {
            if (this.currentClickedDocumentInfo.docId === record.docId) return
            this.currentClickedDocumentInfo = Object.assign({}, record)
            this.$bus.$emit('sendCurrentClickedDocumentInfo', record)
          }
        }
      }
    },

    /**
     * 表格分页、排序改变、筛选时触发
     * @param pagination 分页器选项
     * @param filters 筛选选项
     * @param sorter 排序选项
     */
    handleTableChange(pagination, filters, sorter) {
      if (sorter.order) {
        this.isorter.column = sorter.field
        this.isorter.order = sorter.order === 'ascend' ? 'asc' : 'desc'
      } else {
        this.isorter.column = 'createTime'
        this.isorter.order = 'desc'
      }
      for (let key in filters) {
        this.filters[key] = filters[key].join(',')
      }
      this.ipagination = pagination
      this.loadData()
    },

    handleDocumentEdit(record, modalTitle) {
      if (!this.$refs.modalForm) return
      this.$refs.modalForm.edit(record)
      this.$refs.modalForm.title = modalTitle
    },

    handleDocumentAssign(record, modalTitle) {
      if (!this.$refs.documentAssignModalRef) return
      this.$refs.documentAssignModalRef.title = modalTitle
      this.$refs.documentAssignModalRef.visible = true
    },

    handleDelete() {
      // 此处函数为屏蔽mixins中的同名函数，通用函数写在父级中
    },

    triggerCorrespondingMethod({ methodName, level, modalTitle, tableRowInfo }) {
      if (this[methodName] && tableRowInfo.param === 'NC') this[methodName](tableRowInfo, modalTitle)
    }
  }
}
</script>

<style scoped>

</style>